@@ -16,8 +16,8 @@ from .particles import Particle, MoleculeSTS
 
 
 def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarray:
-    """Loads interaction parameters for two partners for use in various integrals (loads IPL and VSS
-    potential parameters + calculates collision radius, Lennard-Jones :math:`\\varepsilon_{cd}`
+    """Loads interaction parameters for two partners for use in various integrals (loads IPL, VSS and ESA model
+    potential parameters; also calculates collision radius, the Lennard-Jones :math:`\\varepsilon_{cd}`
     parameter and collision-reduced mass :math:`m_{cd}`)
     from the file interactions.csv
     The values are stored in the file as the following units:
@@ -75,7 +75,7 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
             # res[3:] = [rd[0], rd[1], rd[2], rd[3], rd[4], rd[5], rd[6], rd[7], rd[8], rd[9]]
             res[3:] = rd[:]
 
-    if found is False:
+    if not found:
         raise KineticlibError('No interaction data found for particles ' + partner1.name + ', ' + partner2.name)
     else:
         res[3] *= constants.physical_constants['electron volt'][0] / constants.k
@@ -86,8 +86,8 @@ def load_elastic_parameters(partner1: Particle, partner2: Particle) -> np.ndarra
 
 
 def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np.ndarray:
-    """Loads dissociation model parameters for Arrhenius model for the reaction
-    molecule + partner -> atom1 + atom2 + partner.
+    """Loads dissociation model parameters for the Arrhenius model for the reaction
+    **Molecule + Partner -> Atom1 + Atom2 + Partner**.
     The model for the equilibrium reaction rate coefficient is considered to be as follows:
     :math:`k_{diss} = A T^{n}`
 
@@ -122,6 +122,6 @@ def load_dissociation_parameters(molecule: MoleculeSTS, partner: Particle) -> np
             res = np.array(dat).astype(np.float64)
             res[1] *= (10 ** 16) / constants.N_A
             return res
-    if found is False:
+    if not found:
         raise KineticlibError('No dissociation data found for particles '
                               + molecule_name + ', ' + partner_name)
\ No newline at end of file
