@@ -23,9 +23,9 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     r : int
-        the r degree of the integral
+        the `r` degree of the integral
     idata : 1-D array-like
         the array of interaction data
     model : str
@@ -38,13 +38,14 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
               and for the IPL potential otherwise)
             * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
 
-        defaults to 'IPL'
+        defaults to 'ESA'
     dimensional : bool
-        if True, then the dimensional :math:`\\Omega^{(l,r)}`-integral is returned, otherwise,
-        the dimensionless :math:`\\Omega^{(l,r)}`-integral is returned (dimensional integral divided by the same
-        integral for the Rigid Sphere model), defaults to True
+        if ``True``, then the dimensional :math:`\\Omega^{(l,r)}`-integral is returned, otherwise,
+        the dimensionless :math:`\\Omega^{(l,r)}`-integral is returned (the dimensional integral divided by the
+        integral of the same degrees calculated using the Rigid Sphere model), defaults to ``True``
     nokt : bool, optional
-        if True and `dimensional` is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+        if ``True`` and ``dimensional`` is ``True``,
+        the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
 
     Returns
     -------
@@ -54,14 +55,15 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
     Raises
     ------
     KineticlibError
-        For the 'VSS', 'LJ', 'IPL' and 'Switch' models: if `l!=r` or `l` not in `{1,2}`,
-        for the 'ESA' model: if `(l,r)` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
+        For the ``'VSS'``, ``'LJ'``, ``'IPL'`` and ``'Switch'`` models: if ``l!=r`` or ``l`` not in `{1,2}`,
+        for the ``'ESA'`` model: if ``(l,r)`` not in `{(1,1),
+        (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
     """
 
     if model == 'ESA':
-        if dimensional is True:
-            return omega_dimensionless_esa(T, l, r, idata[13], idata[14])\
-                   * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
+        if dimensional:
+            return omega_dimensionless_esa(T, l, r, idata[13], idata[14]) * omega_rigid_sphere(T, l, r, idata[1],
+                                                                                               idata[0], nokt)
         else:
             return omega_dimensionless_esa(T, l, r, idata[13], idata[14])
     elif model == 'Switch' and l == r:
@@ -69,30 +71,30 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
             om_dimless = omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
         else:
             om_dimless = omega_dimensionless_LJ(T, l, idata[2])
-        if dimensional is True:
-            return om_dimless * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
+        if dimensional:
+            return om_dimless * omega_rigid_sphere(T, l, r, idata[1], idata[0], nokt)
         else:
             return om_dimless
     elif model == 'LJ' and l == r:
-        if dimensional is True:
-            return omega_dimensionless_LJ(T, l, idata[2]) * omega_rigid_sphere(T, l, l, idata[0], idata[1], nokt)
+        if dimensional:
+            return omega_dimensionless_LJ(T, l, idata[2]) * omega_rigid_sphere(T, l, l, idata[1], idata[0], nokt)
         else:
             return omega_dimensionless_LJ(T, l, idata[2])
     elif model == 'IPL' and l == r:
-        if dimensional is True:
+        if dimensional:
             return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])\
-                   * omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
+                   * omega_rigid_sphere(T, l, r, idata[1], idata[0], nokt)
         else:
             return omega_dimensionless_IPL(T, l, idata[1], idata[2], idata[3], idata[4])
     elif model == 'VSS' and l == r:
-        if dimensional is True:
+        if dimensional:
             return omega_vss(T, l, idata[0], idata[5 + 2 * (l - 1)], idata[6 + 2 * (l - 1)], nokt)
         else:
             return omega_vss(T, l, idata[0], idata[5 + 2 * (l - 1)], idata[6 + 2 * (l - 1)], nokt)\
-                   / omega_rigid_sphere(T, l, r, idata[0], idata[1], False)
+                   / omega_rigid_sphere(T, l, r, idata[1], idata[0], False)
     elif model == 'RS':
-        if dimensional is True:
-            return omega_rigid_sphere(T, l, r, idata[0], idata[1], nokt)
+        if dimensional:
+            return omega_rigid_sphere(T, l, r, idata[1], idata[0], nokt)
         else:
             return 1.0
     else:
@@ -100,30 +102,30 @@ def omega(T: float, l: int, r: int, idata: np.ndarray, model: str='ESA', dimensi
                               + ')} integral using the ' + model + ' potential')
 
 
-def omega_rigid_sphere(T: float, l: int, r: int, mass: float, sigma: float, nokt: bool=False) -> float:
-    """Returns the :math:`\\Omega^{(l,r)}`-integral for a rigid sphere potential for any `l > 0` and `r > 0`
+def omega_rigid_sphere(T: float, l: int, r: int, sigma: float, mass: float, nokt: bool=False) -> float:
+    """Returns the :math:`\\Omega^{(l,r)}`-integral for a rigid sphere potential for any ``l > 0`` and ``r > 0``
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     r : int
-        the r degree of the integral
+        the `r` degree of the integral
     mass : float
         the collision-reduced mass :math:`m_{cd}`
     sigma : float
         the collision diameter :math:`\\sigma_{cd}`
     nokt : bool, optional
-        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
 
     Returns
     -------
     float
         The calculated rigid sphere omega integral
     """
-    if nokt is False:
+    if not nokt:
         mult = (T * constants.k / (2.0 * constants.pi * mass)) ** 0.5
     else:
         mult = (1.0 / (2.0 * constants.pi * mass)) ** 0.5
@@ -132,14 +134,15 @@ def omega_rigid_sphere(T: float, l: int, r: int, mass: float, sigma: float, nokt
 
 
 def omega_dimensionless_LJ(T: float, l: int, eps: float) -> float:
-    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the Lennard Jones potential (for `l=1` and `l=2`)
+    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the Lennard Jones potential (for
+    ``l=1`` and ``l=2``)
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     eps : float
         the Lennard-Jones :math:`\\varepsilon_{cd}` parameter, divided by Boltzmann's constant
 
@@ -151,7 +154,7 @@ def omega_dimensionless_LJ(T: float, l: int, eps: float) -> float:
     Raises
     ------
     KineticlibError
-        if `l` not in `{1,2}`
+        if ``l`` not in `{1,2}`
     """
     if l == 1:
         tmp = np.log(T / eps) + 1.4
@@ -167,14 +170,14 @@ def omega_dimensionless_LJ(T: float, l: int, eps: float) -> float:
 
 
 def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero: float, beta: float) -> float:
-    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the IPL potential (for `l=1` and `l=2`)
+    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the IPL potential (for ``l=1`` and ``l=2``)
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     sigma : float
         the collision diameter :math:`\\sigma_{cd}`
     eps : float
@@ -192,7 +195,7 @@ def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero:
     Raises
     ------
     KineticlibError
-        if `l` not in `{1,2}`
+        if ``l`` not in `{1,2}`
     """
     Tstar = T / eps
     vstar = phizero / eps
@@ -223,14 +226,14 @@ def omega_dimensionless_IPL(T: float, l: int, sigma: float, eps: float, phizero:
 
 
 def omega_vss(T: float, l: int, mass: float, vssc: float, vsso: float, nokt: bool=False) -> float:
-    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the VSS potential (for `l=1` and `l=2`)
+    """Returns the dimensionless :math:`\\Omega^{(l,l)}`-integral for the VSS potential (for ``l=1`` and ``l=2``)
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     mass : float
         the collision-reduced mass :math:`m_{cd}`
     vssc : float
@@ -238,7 +241,7 @@ def omega_vss(T: float, l: int, mass: float, vssc: float, vsso: float, nokt: boo
     vsso : float
         the VSS potential :math:`\\omega` parameter
     nokt : bool, optional
-        if True and full_integral is True, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to False
+        if ``True``, the result will be multiplied by :math:`\\sqrt{(1 / kT)}`, defaults to ``False``
 
     Returns
     -------
@@ -248,9 +251,9 @@ def omega_vss(T: float, l: int, mass: float, vssc: float, vsso: float, nokt: boo
     Raises
     ------
     KineticlibError
-        if `l` not in `{1,2}`
+        if ``l`` not in `{1,2}`
     """
-    if nokt is False:
+    if not nokt:
         mult = ((T * constants.k / (2 * constants.pi * mass)) ** 0.5)
     else:
         mult = ((1 / (2 * constants.pi * mass)) ** 0.5)
@@ -273,9 +276,9 @@ def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -
     T : float
         the temperature of the mixture
     l : int
-        the l degree of the integral
+        the `l` degree of the integral
     r : int
-        the r degree of the integral
+        the `r` degree of the integral
     beta : float
         the math:`\\beta` parameter for the ESA model
     eps : float
@@ -289,7 +292,7 @@ def omega_dimensionless_esa(T: float, l: int, r: int, beta: float, eps: float) -
     Raises
     ------
     KineticlibError
-        if `(l,r)` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
+        if ``(l,r)`` not in `{(1,1), (1,2), (1,3), (1,4), (1,5), (2,2), (2,3), (2,4), (3,3), (4,4)}`
     """
     x = np.log(T * constants.k / eps)
     coeff_array = np.zeros([7, 3])
