@@ -139,28 +139,29 @@ class MoleculeSTS(Particle):
         The model of the vibrational spectrum (can be either 'harmonic', 'anharmonic' or 'table', if pre-calculated
         table values are used for each vibrational level)
     rot_symmetry : float
-        Equals 2.0 if the molecule is homonuclear and 1.0 otherwise
+        The rotational symmetry factor (equal to 2.0 if the molecule is homonuclear and to 1.0 otherwise)
     num_rot : int
-        The amount of rotational levels in the molecule
+        The number of rotational levels in the molecule
     num_vibr : int
-        The amount of vibrational levels in the molecule
+        The number of vibrational levels in the molecule
     inertia : float
-        The moment of rotational inertia
+        The moment of rotational inertia :math:`I_{rot,c}`
     rot_const : float
         The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
         inertia
     hvc : float
         The harmonic coefficient in the formula for vibrational level energies
     avc : float
-        The anharmonic coefficient in the formula for vibrational level nergies
+        The anharmonic coefficient in the formula for vibrational level energies
     diss : float
-        The dissociation energy
+        The dissociation energy of the molecule
     rot : ndarray
-        The array of rotational energies
+        The array of rotational energies for each level
     vibr : ndarray
-        The array of vibrational energies
+        The array of vibrational energies for each level
     vibr_zero : float
-        The energy of the 0th vibrational level
+        The energy of the 0th vibrational level (stored separately as the value of the energy of
+        the 0th vibrational level in the ``vibr`` array is equal to 0)
     crot : float
         The specific heat capacity of rotational degrees of freedom
     _current_T : float
@@ -275,7 +276,7 @@ class MoleculeSTS(Particle):
         self._current_T = T
 
     def vibr_energy(self, i):
-        """Returns the energy of the `i`-th vibrational level :math:`\\varepsilon_{i}`
+        """Returns the energy of the ``i``-th vibrational level :math:`\\varepsilon_{i}`
 
         Parameters
         ----------
@@ -285,13 +286,13 @@ class MoleculeSTS(Particle):
         Returns
         -------
         float or 1-D array-like
-            The energy of the i-th vibrational level, or, if the input the `i` parameter is array-like, an array of
+            The energy of the i-th vibrational level, or, if the input the ``i`` parameter is array-like, an array of
             vibrational energies
         """
         return self.vibr[i]
 
     def rot_energy(self, j):
-        """Returns the energy of the `j`-th rotational level :math:`\\varepsilon_{j}`
+        """Returns the energy of the ``j``-th rotational level :math:`\\varepsilon_{j}`
 
         Parameters
         ----------
@@ -301,7 +302,7 @@ class MoleculeSTS(Particle):
         Returns
         -------
         float or 1-D array-like
-            The energy of the j-th rotational level, (`float` values of `j` are used for integration)
+            The energy of the ``j``-th rotational level, (`float` values of ``j`` are used for integration)
         """
         if (int(j) - j) == 0 and j <= self.num_rot:
             return self.rot[j]
@@ -309,8 +310,8 @@ class MoleculeSTS(Particle):
             return j * (j + 1) * self.rot_const
 
     def full_energy(self, i, j):
-        """Returns the sum of the energy of the `j`-th rotational level and the energy of the `i`-th vibrational level
-        (the total energy of the `ij`-th rotovibrational state) :math:`\\varepsilon_{ij}`
+        """Returns the sum of the energy of the ``j``-th rotational level and the energy of the ``i``-th vibrational
+        level (the total energy of the `ij`-th rotovibrational state) :math:`\\varepsilon_{ij}`
 
         Parameters
         ----------
@@ -326,7 +327,7 @@ class MoleculeSTS(Particle):
 
         Notes
         -----
-        The dimensions of `i` and `j` must match
+        The dimensions of ``i`` and ``j`` must match
         """
         return self.vibr[i] + self.rot[j]
 
@@ -346,7 +347,7 @@ class MoleculeSTS(Particle):
         Returns
         -------
         float or 1-D np.ndarray
-            The rotational exponent for a given index `j`
+            The rotational exponent for a given index ``j``
         """
         return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot_energy(j) / (constants.k * T))
 
@@ -391,15 +392,15 @@ class MoleculeSTS(Particle):
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1.0)
 
-            if dimensional is True:
+            if dimensional:
                 return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
             else:
                 return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
         else:
-            if dimensional is False:
-                return self._current_rae_dimensionless
-            else:
+            if dimensional:
                 return self._current_rae
+            else:
+                return self._current_rae_dimensionless
 
     def avg_rot_energy_sq(self, T: float, dimensional: bool=True) -> float:
         """
@@ -424,21 +425,22 @@ class MoleculeSTS(Particle):
             kT = constants.k * T
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1)
-            if dimensional is True:
+            if dimensional:
                 return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
                                                                                                 * self.Z_rot(T) * B)
             else:
                 return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
                                                                                     * self.Z_rot(T) * B)
         else:
-            if dimensional is False:
-                return self._current_raesq_dimensionless
-            else:
+            if dimensional:
                 return self._current_raesq
+            else:
+                return self._current_raesq_dimensionless
 
     def Z_vibr_eq(self, T: float, model: str='none') -> float:
         """Returns the equilibrium vibrational partition function :math:`Z_{eq}(T)` (which is used in various
-        dissociation models) as a function of the temperature T and a parameter U ('model'). If U is equal to 0,
+        dissociation models) as a function of either the temperature T or the parameter U (specified by ``model``).
+        If U is equal to 0,
         the result is just the equilibirum vibrational partition function (except that the the vibrational energy
         at the zero level is not equal to zero); otherwise, the parameter U is used instead of the temperature T
 
@@ -474,8 +476,8 @@ class MoleculeSTS(Particle):
 
     def Z_diss(self, i, T: float, model: str='D6k'):
         """Returns the non-equilibrium factor (which is used in various
-        dissociation models) as a function of the temperature T and a parameter U ('model') and
-        the vibrational level `i`, which is equal to
+        dissociation models) as a function of the temperature T and a parameter U (specified by ``model``) and
+        the vibrational level ``i``, which is equal to
         :math:`Z_{eq}(T) \\exp(\\varepsilon_{i} (1 / T + 1 / U) / k) / Z_{eq}(-U)`
 
         Parameters
@@ -486,10 +488,12 @@ class MoleculeSTS(Particle):
             the temperature of the mixture
         model : str
             the model for the parameter `U` to be used, possible values:
-                * 'inf' - the method will return `Z_vibr_eq(-infinity, 0)`
-                * 'D6k' - the method will return `Z_vibr_eq(-D / 6k, 0)` (where `D` is the dissociation energy of
+                * 'inf' - the method will use `Z_vibr_eq(-infinity, 0)`
+                * 'D6k' - the method will use `Z_vibr_eq(-D / 6k, 0)` (where `D` is the dissociation energy of
                   the molecule)
-                * '3T' - the method will return `Z_vibr_eq(-3T, 0)`
+                * '3T' - the method will use `Z_vibr_eq(-3T, 0)`
+
+            defaults to 'D6k'
 
         Returns
         -------
@@ -528,28 +532,29 @@ class Molecule(MoleculeSTS):
         The model of the vibrational spectrum (can be either 'harmonic', 'anharmonic' or 'table', if pre-calculated
         table values are used for each vibrational level)
     rot_symmetry : float
-        Equals 2.0 if the molecule is homonuclear and 1.0 otherwise
+        The rotational symmetry factor (equal to 2.0 if the molecule is homonuclear and to 1.0 otherwise)
     num_rot : int
-        The amount of rotational levels in the molecule
+        The number of rotational levels in the molecule
     num_vibr : int
-        The amount of vibrational levels in the molecule
+        The number of vibrational levels in the molecule
     inertia : float
-        The moment of rotational inertia
+        The moment of rotational inertia :math:`I_{rot,c}`
     rot_const : float
         The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
         inertia
     hvc : float
         The harmonic coefficient in the formula for vibrational level energies
     avc : float
-        The anharmonic coefficient in the formula for vibrational level nergies
+        The anharmonic coefficient in the formula for vibrational level energies
     diss : float
-        The dissociation energy
+        The dissociation energy of the molecule
     rot : ndarray
-        The array of rotational energies
+        The array of rotational energies for each level
     vibr : ndarray
-        The array of vibrational energies
+        The array of vibrational energies for each level
     vibr_zero : float
-        The energy of the 0th vibrational level
+        The energy of the 0th vibrational level (stored separately as the value of the energy of
+        the 0th vibrational level in the ``vibr`` array is equal to 0)
     crot : float
         The specific heat capacity of rotational degrees of freedom
     _current_T : float
@@ -670,7 +675,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         n_c : float
             the numeric density of the molecular species
         """
@@ -709,17 +714,17 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         true_amt : bool
             if True, the true amount of vibrational levels is returned (which may be smaller than the maximum one if
             T < T1), if False, the maximum amount of vibrational levels is returned, defaults to True
 
         Returns
         -------
-        bool
+        int
             The amount of vibrational levels
         """
-        if true_amt is False:
+        if not true_amt:
             return self.max_vibr
         else:
             if (self._current_T != T) or (self._current_T1 != T1):
@@ -748,7 +753,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -769,7 +774,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -789,7 +794,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -804,14 +809,14 @@ class Molecule(MoleculeSTS):
     def avg_vibr_energy(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the vibrational energy averaged over the vibrational spectrum (either dimensional
         :math:`\\left<\\varepsilon^{vibr} \\right>_{vibr}` or dimensionless
-        :math:`\\left<\\varepsilon^{vibr} / kT \\right>_{vibr})`
+        :math:`\\left<\\varepsilon^{vibr} / kT \\right>_{vibr}`)
 
         Parameters
         ----------
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         dimensional : bool
             if True, the dimensional averaged vibrational energy is returned, if False, the dimensionless averaged
             vibrational energy is returned, defaults to True
@@ -823,12 +828,12 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            if dimensional is True:
+            if dimensional:
                 return np.dot(self.vibr_exp(a, T, T1), self.vibr[a]) / self.Z_vibr(T, T1)
             else:
                 return np.dot(self.vibr_exp(a, T, T1), self.vibr[a] / (constants.k * T)) / self.Z_vibr(T, T1)
         else:
-            if dimensional is True:
+            if dimensional:
                 return self._current_vae
             else:
                 return self._current_vae_dimensionless
@@ -836,14 +841,14 @@ class Molecule(MoleculeSTS):
     def avg_full_energy(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the full internal energy averaged over the internal spectrum (either dimensional
         :math:`\\left<\\varepsilon^{int} \\right>_{int}` or dimensionless
-        :math:`\\left<\\varepsilon^{int} / kT \\right>_{int})`
+        :math:`\\left<\\varepsilon^{int} / kT \\right>_{int}`)
 
         Parameters
         ----------
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         dimensional : bool
             if True, the dimensional averaged internall energy is returned, if False, the dimensionless averaged
             internal energy is returned, defaults to True
@@ -855,17 +860,17 @@ class Molecule(MoleculeSTS):
         """
         return self.avg_vibr_energy(T, T1, dimensional) + self.avg_rot_energy(T, dimensional)
 
-    def avg_vibr_energy_sq(self, T: float, T1: float, dim: bool=True) -> float:
+    def avg_vibr_energy_sq(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the squared vibrational energy averaged over the vibrational spectrum (either dimensional
         :math:`\\left<\\left(\\varepsilon^{vibr} \\right)^{2}\\right>_{vibr}`
-        or dimensionless :math:`\\left<\\left(\\varepsilon^{vibr} / kT \\right)^{2}\\right>_{vibr})`
+        or dimensionless :math:`\\left<\\left(\\varepsilon^{vibr} / kT \\right)^{2}\\right>_{vibr}`)
 
         Parameters
         ----------
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         dimensional : bool
             if True, the averaged squared dimensional vibrational energy is returned, if False, the averaged squared
             dimensionless vibrational energy is returned, defaults to True
@@ -877,16 +882,16 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            if dim is True:
+            if dimensional:
                 return np.dot(self.vibr_exp(a, T, T1), np.power(self.vibr[a], 2)) / self.Z_vibr(T, T1)
             else:
                 return np.dot(self.vibr_exp(a, T, T1), np.power(self.vibr[a] / (constants.k * T), 2))\
                        / self.Z_vibr(T, T1)
         else:
-            if dim is False:
-                return self._current_vaesq_dimensionless
-            else:
+            if dimensional:
                 return self._current_vaesq
+            else:
+                return self._current_vaesq_dimensionless
 
     def avg_i(self, T: float, T1: float) -> float:
         """Returns the average amount of vibrational quanta :math:`<i>_{vibr}`
@@ -896,7 +901,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -919,7 +924,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -936,14 +941,14 @@ class Molecule(MoleculeSTS):
     def avg_vibr_energy_i(self, T: float, T1: float, dimensional: bool=True) -> float:
         """Returns the energy level multiplied by the corresponding vibrational energy, averaged over the vibrational
         spectrum (either dimensional :math:`\\left<i\\varepsilon_{i} \\right>_{vibr}` or dimensionless
-        :math:`\\left<i\\varepsilon_{i} / kT \\right>_{vibr})`
+        :math:`\\left<i\\varepsilon_{i} / kT \\right>_{vibr}`)
 
         Parameters
         ----------
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         dimensional : bool
             if True, the averaged dimensional vibrational energy multiplied by the corresponding level number
             is returned, if False, the averaged dimensionless vibrational energy by the corresponding level number is
@@ -956,18 +961,18 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            if dimensional is True:
+            if dimensional:
                 return np.dot(a * self.vibr[a], self.vibr_exp(a, T, T1)) / self.Z_vibr(T, T1)
             else:
                 return np.dot(a * self.vibr[a] / (constants.k * T), self.vibr_exp(a, T, T1)) / self.Z_vibr(T, T1)
         else:
-            if dimensional is False:
-                return self._current_vae_i_dimensionless
-            else:
+            if dimensional:
                 return self._current_vae_i
+            else:
+                return self._current_vae_i_dimensionless
 
     def ni(self, i, T: float, T1: float, n_c: float) -> float:
-        """Returns the numeric density of the `i`-th vibrational level :math:`n_{i}` for the molecular species
+        """Returns the numeric density of the ``i``-th vibrational level :math:`n_{i}` for the molecular species
 
         Parameters
         ----------
@@ -976,7 +981,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
         n_c : float
             the numeric density of the molecular species
 
@@ -999,7 +1004,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1021,7 +1026,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1044,7 +1049,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1071,7 +1076,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1094,7 +1099,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1112,7 +1117,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
@@ -1139,7 +1144,7 @@ class Molecule(MoleculeSTS):
         T : float
             the temperature of the mixture
         T1 : float
-            the temperature of the first vibrational level for the molecular species
+            the temperature of the first vibrational level of the molecular species
 
         Returns
         -------
