@@ -16,8 +16,7 @@ import numpy as np
 
 def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, infcoll: float,
                  model: str='ESA') -> float:
-    """
-    Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
+    """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral
 
     Parameters
     ----------
@@ -28,7 +27,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, i
     molecule : MoleculeSTS or Molecule
         the molecule for which the rotational relaxation time is being calculated
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
@@ -41,7 +40,7 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, i
               and for the IPL potential otherwise)
             * 'ESA' (model given in the paper *Transport Properties of High-Temperature Mars-Atmosphere Components*)
 
-        defaults to 'IPL'
+        defaults to 'ESA'
 
     Returns
     -------
@@ -51,8 +50,9 @@ def rot_rel_time(T: float, idata: np.ndarray, molecule: MoleculeSTS, n: float, i
     return raw_rot_rel_time(T, omega(T, 2, 2, idata, model=model, nokt=False), molecule.LJe, n, infcoll)
 
 
-def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner: Particle, n: float) -> float:
-    """ Calculates the rotational relaxation time using the definition (through the averaging of the squared
+def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner: Particle, n: float,
+                     rig_sphere: bool=False) -> float:
+    """Calculates the rotational relaxation time using the definition (through the averaging of the squared
     rotational energy difference)
 
     Parameters
@@ -66,7 +66,10 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
     partner : Particle
         the collision partner
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
 
     Returns
     -------
@@ -74,20 +77,20 @@ def rot_rel_time_def(T: float, idata: np.ndarray, molecule: MoleculeSTS, partner
         Rotational relaxation time
     """
     if isinstance(partner, MoleculeSTS):
-        return raw_rot_tel_time_def_molecule_partner(T, idata[1], idata[0], idata[9], idata[10],
+        return raw_rot_rel_time_def_molecule_partner(T, idata[1], idata[0], idata[9], idata[10],
                                                      molecule.Z_rot(T), partner.Z_rot(T),
                                                      molecule.rot_symmetry, partner.rot_symmetry, molecule.rot_const,
                                                      partner.rot_const, molecule.num_rot, partner.num_rot,
-                                                     molecule.name, partner.name, n)
+                                                     molecule.name == partner.name, n, rig_sphere)
     else:
         return raw_rot_rel_time_def_atom_partner(T, idata[1], idata[0], idata[9], idata[10],
                                                  molecule.Z_rot(T), molecule.rot_symmetry, molecule.rot_const,
-                                                 molecule.num_rot, n)
+                                                 molecule.num_rot, n, rig_sphere)
 
 
 def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
                      n: float, infcoll: float, model: str='VSS') -> float:
-    """ Calculates the rotational relaxation time using the VSS/VHS/HS models and Parker's formula
+    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula
 
     Parameters
     ----------
@@ -97,13 +100,15 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
         the array of interaction data
     molecule : MoleculeSTS or Molecule
         the molecule for which the rotational relaxation time is being calculated
+    n : float
+        the numeric density of the mixture
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
         the interaction model to be used, possible values:
             * 'VSS' (Variable Soft Sphere model)
             * 'VHS' (Variable Hard Sphere model)
-            * the Rigid Sphere model will be used otherwise
+            * the rigid sphere model will be used otherwise
 
         defaults to 'VSS'
 
@@ -117,16 +122,14 @@ def rot_rel_time_VSS(T: float, idata: np.ndarray, molecule: MoleculeSTS,
 
 
 def Zr_original(T: float, molecule: MoleculeSTS, infcoll: float) -> float:
-    """
-    Calculates the collision amount needed to reach rotational equilibrium for the hard sphere model, but has an
-    additional addendum, *raw* version
+    """Calculates the collision amount needed to reach rotational equilibrium for the rigid sphere model
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
     molecule : MoleculeSTS or Molecule
-        the molecule for which the rotational relaxation time is being calculated
+        the molecule for which the collision amount is being calculated
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
 
@@ -139,8 +142,7 @@ def Zr_original(T: float, molecule: MoleculeSTS, infcoll: float) -> float:
 
 
 def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model: str='VSS') -> float:
-    """
-    Calculates the collision amount needed to reach rotational equilibrium for different models
+    """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models
 
     Parameters
     ----------
@@ -149,14 +151,14 @@ def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model
     idata : 1-D array-like
         the array of interaction data
     molecule : MoleculeSTS or Molecule
-        the molecule for which the rotational relaxation time is being calculated
+        the molecule for which the collision amount is being calculated
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
         the interaction model to be used, possible values:
             * 'VSS' (Variable Soft Sphere model)
             * 'VHS' (Variable Hard Sphere model)
-            * the Rigid Sphere model will be used otherwise
+            * the rigid sphere model will be used otherwise
 
         defaults to 'VSS'
 
@@ -169,7 +171,7 @@ def Zr(T: float, idata: np.ndarray, molecule: MoleculeSTS, infcoll: float, model
 
 
 def millikan_white(T: float, idata: np.ndarray, molecule: MoleculeSTS, p: float) -> float:
-    """ Calculates the VT relaxation time using the Millikan-White formula
+    """Calculates the VT relaxation time using the Millikan-White formula
 
     Parameters
     ----------
@@ -191,20 +193,19 @@ def millikan_white(T: float, idata: np.ndarray, molecule: MoleculeSTS, p: float)
 
 
 def raw_rot_rel_time(T: float, omega_integral: float, eps: float, n: float, infcoll: float) -> float:
-    """
-    Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral,
+    """Calculates the rotational relaxation time using Parker's formula and the :math:`\\Omega^{(2,2)}` integral,
     *raw* version
 
     Parameters
     ----------
     T : float
         the temperature of the mixture
-    idata : 1-D array-like
-        the array of interaction data
+    omega_integral : float
+        the value of the dimensional :math:`\\Omega^{(2,2)}` integral to be used in the calculation
     eps : float
         the Lennard-Jones :math:`\\varepsilon_{cd}` parameter of the molecule, divided by Boltzmann's constant
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
 
@@ -216,14 +217,14 @@ def raw_rot_rel_time(T: float, omega_integral: float, eps: float, n: float, infc
     return 0.15625 * (constants.pi ** 2) * raw_Zr_original(T, eps, infcoll) / (n * omega_integral)  # 0.15625 is 5 / 32
 
 
-def raw_rot_tel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
+def raw_rot_rel_time_def_molecule_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
                                           Z_rot1: float, Z_rot2: float,
                                           molecule_rot_symmetry1: float, molecule_rot_symmetry2: float,
                                           molecule_rot_const1: float, molecule_rot_const2: float,
-                                          molecule_num_rot1: int, molecule_num_rot2: int, molecule_name: str,
-                                          partner_name: str, n: float) -> float:
-    """ Calculates the rotational relaxation time using the definition (through the averaging of the squared
-    rotational energy difference), *raw* version for the case when the partner is a molecule
+                                          molecule_num_rot1: int, molecule_num_rot2: int, same_partner: bool,
+                                          n: float, rig_sphere: bool=False) -> float:
+    """Calculates the rotational relaxation time using the definition (through the averaging of the squared
+    rotational energy difference) for the case when the partner is a molecule, *raw* version
 
     Parameters
     ----------
@@ -234,9 +235,9 @@ def raw_rot_tel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
     mass : float
         the collision-reduced mass :math:`m_{cd}`
     vssc : float
-        the elastic crosssection VSS potential :math:`C` parameter
+        the VSS potential :math:`C` parameter
     vsso : float
-        the elastic crosssection VSS potential :math:`\\omega` parameter
+        the VSS potential :math:`\\omega` parameter
     Z_rot1 : float
         the value of the rotational partition function of the first molecule
     Z_rot2 : float
@@ -246,21 +247,23 @@ def raw_rot_tel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
     molecule_rot_symmetry2 : float
         should equal 2.0 if the second molecule is homonuclear and 1.0 otherwise
     molecule_rot_const1 : float
-        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
         inertia of the first molecule
     molecule_rot_const2 : float
-        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
         inertia of the second molecule
     molecule_num_rot1 : int
         the amount of rotational levels in the first molecule
     molecule_num_rot2 : int
         the amount of rotational levels in the second molecule
-    molecule_name : str
-        the name of the relaxating molecule
-    partner_name : str
-        the name of the collision partner molecule
+    same_partner : bool
+        if the collision partner is of the same molecular species, should be set to ``True``, otherwise should be
+        set to ``False``
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
 
     Returns
     -------
@@ -268,26 +271,27 @@ def raw_rot_tel_time_def_molecule_partner(T: float, sigma: float, mass: float, v
         Rotational relaxation time
     """
 
-    if molecule_name == partner_name:
-        return 0.5 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso)
+    if same_partner:
+        return 0.5 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
                       * (2 * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot1, molecule_rot_symmetry1,
-                                              molecule_rot_const1, molecule_num_rot1, False, False)
+                                              molecule_rot_const1, molecule_num_rot1, False, False, False)
                          + 2 * cs.raw_dE_rot_c_dE_rot_d(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2,
                                                         molecule_rot_symmetry1, molecule_rot_symmetry2,
                                                         molecule_rot_const1, molecule_rot_const2,
-                                                        molecule_num_rot1, molecule_num_rot2, False, False)))
+                                                        molecule_num_rot1, molecule_num_rot2, False, False, False)))
     else:
-        return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso)
+        return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
                        * cs.raw_dE_rot_dE_rot_full(T, sigma, mass, vssc, vsso, Z_rot1, Z_rot2, molecule_rot_symmetry1,
                                                    molecule_rot_symmetry2, molecule_rot_const1, molecule_rot_const2,
-                                                   molecule_num_rot1, molecule_num_rot2, False, False))
+                                                   molecule_num_rot1, molecule_num_rot2, False, False, False))
         
         
 def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc: float, vsso: float,
                                       Z_rot: float, molecule_rot_symmetry: float,
-                                      molecule_rot_const: float, molecule_num_rot: int, n: float) -> float:
-    """ Calculates the rotational relaxation time using the definition (through the averaging of the squared
-    rotational energy difference), *raw* version for the case when the partner is an atom
+                                      molecule_rot_const: float, molecule_num_rot: int, n: float,
+                                      rig_sphere: bool=False) -> float:
+    """Calculates the rotational relaxation time using the definition (through the averaging of the squared
+    rotational energy difference) for the case when the partner is an atom, *raw* version
 
     Parameters
     ----------
@@ -306,26 +310,30 @@ def raw_rot_rel_time_def_atom_partner(T: float, sigma: float, mass: float, vssc:
     molecule_rot_symmetry : float
         should equal 2.0 if the molecule is homonuclear and 1.0 otherwise
     molecule_rot_const : float
-        The quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
+        the quantity :math:`h ^ 2 / (8 \\pi ^ 2 I_{rot,c})`, where :math:`I_{rot,c}` is the moment of rotational
         inertia of the molecule
     molecule_num_rot : int
         the amount of rotational levels in the molecule
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
+    rig_sphere : bool, optional
+        if ``True``, the rigid sphere model is used for the crosssection, if ``False``, the VSS is model is used,
+        defaults to ``False``
 
     Returns
     -------
     float
         Rotational relaxation time
     """
-    return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso)
+    return 0.25 / (n * cs.raw_elastic_integral(T, 0, sigma, mass, vssc, vsso, rig_sphere, False)
                    * cs.raw_dE_rot_sq(T, sigma, mass, vssc, vsso, Z_rot, molecule_rot_symmetry,
-                                      molecule_rot_const, molecule_num_rot, False, False))
+                                      molecule_rot_const, molecule_num_rot, False, False, False))
 
 
 def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: float, vsso: float, vssc_deflection: float,
                          vsso_deflection: float, mass: float, n: float, infcoll: float, model: str='VSS') -> float:
-    """ Calculates the rotational relaxation time using the VSS/VHS/HS models and Parker's formula, *raw* version
+    """Calculates the rotational relaxation time using the VSS/VHS/rigid sphere models and Parker's formula,
+    *raw* version
 
     Parameters
     ----------
@@ -346,7 +354,7 @@ def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: floa
     mass : float
         the mass of the molecule for which the rotational relaxation time is being calculated
     n : float
-        the numeric density of the mixtue
+        the numeric density of the mixture
     infcoll : float
         the :math:`\\zeta_{\\inf}` parameter (Parker's limiting value)
     model : str
@@ -369,9 +377,7 @@ def raw_rot_rel_time_VSS(T: float, collision_mass: float, eps: float, vssc: floa
 
 
 def raw_Zr_original(T: float, eps: float, infcoll: float) -> float:
-    """
-    Calculates the collision amount needed to reach rotational equilibrium for the hard sphere model, but has an
-    additional addendum, *raw* version
+    """Calculates the collision amount needed to reach rotational equilibrium for the hard sphere model, *raw* version
 
     Parameters
     ----------
@@ -395,8 +401,8 @@ def raw_Zr_original(T: float, eps: float, infcoll: float) -> float:
 
 def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflection: float, vsso_deflection: float,
            mass: float, infcoll: float, model: str='VSS') -> float:
-    """
-    Calculates the collision amount needed to reach rotational equilibrium for different models, *raw* version
+    """Calculates the collision amount needed to reach rotational equilibrium using the VSS/VHS/rigid sphere models,
+    *raw* version
 
     Parameters
     ----------
@@ -446,7 +452,7 @@ def raw_Zr(T: float, collision_mass: float, eps: float, vsso: float, vssc_deflec
 
 
 def raw_millikan_white(T: float, mass: float, molecule_hvc: float, p: float) -> float:
-    """ Calculates the VT relaxation time using the Millikan-White formula, *raw* version
+    """Calculates the VT relaxation time using the Millikan-White formula, *raw* version
 
     Parameters
     ----------
